#coding=utf-8
#-*-coding:utf-8-*-
#!/usr/bin/env python3
from .home import Third_request
from .courses import get_table
from .grade import get_grade_table, calculate_grade


class Smuer(object):
    """docstring for Smuer"""
    def __init__(self, **kw):

        super(Smuer, self).__init__()
        self.kw = kw
        try:
            self.username = self.kw['username']
        except Exception as e:
            print(e)
            print('username could not be blank')
        try:
            self.password = self.kw['password']
        except Exception as e:
            print(e)
            print('password could not be blank')

    def get_card_info(self, **kw):

        t = Third_request(username=self.username, password=self.password)
        try:
            return t.get_card_money()

        except Exception as e:
            print(e)

    def get_courses_table(self, semester_id):

        table = get_table(semester_id=semester_id,
                          username=self.username,
                          password=self.password
                        )
        return table

    def get_grade_table(self, semester_id):

        table = get_grade_table(semester_id=semester_id,
                          username=self.username,
                          password=self.password
                        )
        return table

    def calculate_grade(self, *semester_id):
        
        average = calculate_grade(*semester_id, username=self.username, password=self.password)
        return average

    def get_active_tiezi(self, **kw):

        r = Third_request(username=self.username, password=self.password)
        return r.get_tiezi()
        
    def get_library_info():
        pass


if __name__ == '__main__':
    from password import my_password, my_username
    s = Smuer(password=my_password,
              username=my_username)
    # print(s.get_courses_table(1))
    print(s.get_active_tiezi())
    print(s.calculate_grade(1))





#-*-coding:utf-8-*-
#coding=utf-8
#! python3

#============
#访问的是教务系统

import requests
import re


class First_request(object):

    def __init__(self, allow_redirects=None):
        URL = 'http://jwxt.shmtu.edu.cn/shmtu/home.action'
        r = requests.get(URL, allow_redirects=allow_redirects)
        self.content = r.text
        self.headers = r.headers

    def get_lt(self):
        content = self.content
        reg = r'<input type="hidden" name="lt" value="(.*)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        lt = result[0]
        return lt

    def get_execution(self):
        content = self.content
        reg = r'<input type="hidden" name="execution" value="(.*?)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        execution = result[0]
        return execution


    def get_cookie(self):
        return self.headers['Set-Cookie'].split(';')[0]

    def get_location(self):
        return self.headers['Location']

    def get_headers(self):
        return self.headers


class Second_request(object):

    def __init__(self,username=None, password=None):

        r1 = First_request(allow_redirects=True)
        lt = r1.get_lt()
        execution = r1.get_execution()
        login_cookie = r1.get_cookie()

        r2 = First_request(allow_redirects=False)
        url = r2.get_location()

        data = {'execution': execution,
                'username': ("%s") % username,
                'password': ("%s") % password,
                'lt': lt,
                '_eventId': 'submit',
                'signin': '登录'
               }
        headers = {'Cookie': login_cookie}
        
        r = requests.post(url,
                          headers=headers,
                          data=data,
                          allow_redirects=False,)
        self.headers = r.headers
        self.status_code = r.status_code

    def get_location(self):
        return self.headers['Location']

    def get_cookie(self):
        return self.headers['Set-Cookie'].split(';')

    def get_status(self):
        return self.status_code 

    def get_headers(self):
        return self.headers


class Third_request(object):

    def __init__(self, username=None, password=None):
        r = Second_request(username=username, password=password)
        url = r.get_location()
        next_r = requests.get(url)
        self.content = next_r.text
        self.headers = next_r.headers
        

    def get_text(self):
        return self.content
        # print(self.content)

    def get_headers(self):
        return self.headers

    def get_cookie(self):
        return self.headers['Set-Cookie']

class Fourth_request(object):

    def __init__(self, username=None, password=None, which_semester=None):
        semester_id = 75+20*(which_semester-1)
        url = 'http://jwxt.shmtu.edu.cn/shmtu/teach/grade/course/person!search.action?semesterId=%s&projectType=' % (semester_id)
        try:
            r = Third_request(username=username, password=password)
            headers = {'Cookie': r.get_cookie()}
            r = requests.post(url, headers=headers)
            self.headers = r.headers
            self.content = r.text
        except Exception as e:
            print(e)

    def get_text(self):
        return self.content
    # print(self.content)

    def get_headers(self):
        return self.headers

    def get_cookie(self):
        return self.headers['Set-Cookie']


class Table(object):
    def __init__(self, username=None, password=None, which_semester=None):
        f = Fourth_request(username=username, password=password, which_semester=which_semester)
        text = f.get_text()
        text = text.replace('\n', 'V').replace('\t', 'V').replace(' ', 'V')

        pattern = r'<tr>VV<td>(.*?)V(.*?)</td>VVV<td>(.*?)</td>VVV<td>(.*?)</td>VVV<td>(.*?)</td>VVV<td>(.*?)</td>VVV<td>(.*?)</td>VVV<td>(.*?)</td>V<tdV(.*?)>VVVVVVVV(.*?)VV</td>VVVVVVVV<td>(.*?)</td>V<tdV(.*?)>VVV(.*?)V</td><td>VVV(.*?)V</td>VVV</tr>'
        r = re.compile(pattern)
        result = r.findall(text)
        self.table = result

    def get_table(self):
        return self.table

class Handle_row(object):

    def __init__(self, row):
        self.row = row
    def get_year(self):
        return self.row[0]
    def get_semester(self):
        return self.row[1]
    def get_id(self):
        return self.row[2]
    def get_order(self):
        return self.row[3]
    def get_name(self):
        return self.row[4]
    def get_type(self):
        return self.row[5]
    def get_kind(self):
        return self.row[6]
    def get_credit(self):
        return self.row[7]
    def get_status(self):
        return self.row[10]
    def get_result(self):
        return self.row[12]
    def get_point(self):
        return self.row[13]




class Calculate(object):
    def __init__(self, username=None, password=None, which_semester=None):
        t = Table(username=username, password=password, which_semester=which_semester)
        table = t.get_table()
        #总学分
        credit_sum = 0
        #总的（学分*绩点）
        cp_sum = 0
        for row in table:
            r = Handle_row(row)
            credit = float(r.get_credit())
            point = float(r.get_point())
            cp_sum += credit*point
            credit_sum += credit
        self.cp_sum = cp_sum
        self.credit_sum = credit_sum
        try:
            self.average_point = cp_sum/credit_sum
        except Exception as e:
            print(e)
            print("")
    def get_cp_sum(self):
        return self.cp_sum
    def get_average_point(self):
        return self.average_point
    def get_credit_sum(self):
        return self.credit_sum

def construct_dict(**kw):
    return kw

def get_grade_table(username, password, semester_id=None):
    t = Table(username=username,
              password=password,
              which_semester=semester_id,
              )
    raw_table = t.get_table()

    new_table = []
    for row in raw_table:
        r = Handle_row(row)
        row_dict = construct_dict(year=r.get_year(),
                                  semester_id=r.get_semester(),
                                  course_name=r.get_name(),
                                  type=r.get_type(),
                                  kind=r.get_kind(),
                                  id=r.get_id(),
                                  order=r.get_order(),
                                  credit=r.get_credit(),
                                  status=r.get_status(),
                                  point=r.get_point(),
                                  result=r.get_result()
                                  )
        new_table.append(row_dict)

    return new_table

    



def calculate_grade(*args, username=None, password=None):

    #cp : produt of (credit*point)
    semester_id_list = args
    cp_sum_list = []
    credit_sum_list = []
    for s in semester_id_list:
        c = Calculate(username=username, password=password, which_semester=s)
        cp_sum = c.get_cp_sum()
        cp_sum_list.append(cp_sum)
        credit_sum = c.get_credit_sum()
        credit_sum_list.append(credit_sum)

    total_credit = 0
    for c in credit_sum_list:
        total_credit += c
    total_cp = 0
    for cp in cp_sum_list:
        total_cp += cp
    try:
        result = total_cp/total_credit
        return round(result, 2)
    except Exception as e:
        print(e)
        return 


if __name__ == '__main__':
    
    print(calculate_grade(1,2, username='', password=''))

    # c = Caculate(username='', password='', which_semester=2)
    # #this semester
    # print(c.get_average_point())
    

    # c = Caculate(username='', password='', which_semester=2)
    # print(c.get_average_point())

    # this_year_ave = caculate_more_average(username='', password='', semester_id_list=[1,2])
    # print(this_year_ave)


#coding=utf-8
#-*-coding:utf-8-*-
#!/usr/bin/env python3


#访问的是数字海大页面


import requests
import re


#访问登录页面获取两个动态参数以及cookie
#这两个动态参数的值藏在登录页面的html里面
#故利用正则匹配出来
class First_request(object):

    def __init__(self):
        URL = 'https://cas.shmtu.edu.cn/cas/login?service=https%3A%2F%2Fportal.shmtu.edu.cn%2Fnode'
        self.url = URL
        self.content = requests.get(URL).text

    def get_lt(self):
        content = self.content
        reg = r'<input type="hidden" name="lt" value="(.*)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        lt = result[0]
        return lt


    def get_execution(self):
        content = self.content
        reg = r'<input type="hidden" name="execution" value="(.*?)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        execution = result[0]
        return execution


    def get_cookie(self):
        r = requests.get(self.url)
        return r.headers['Set-Cookie'].split(';')[0]


#利用第一次请求获取到的参数和cookie post上去
#然后分析响应头，获取location参数的值和cookie
class Second_request(object):

    def __init__(self, username=None, password=None):
        url = 'https://cas.shmtu.edu.cn/cas/login'
        r1 = First_request()
        lt = r1.get_lt()
        execution = r1.get_execution()
        login_cookie = r1.get_cookie()
        self.login_cookie = login_cookie
        data = {'execution': execution,
                'username': username,
                'password': password,
                'lt': lt,
                '_eventId': 'submit',
                'signin': '登录'
               }
        headers = {'Cookie': login_cookie}
        payload = {"service": "https://portal.shmtu.edu.cn/node"}
        
        #因为requests.post会自动重定向，所以此处设置allow_redirects=False
        r = requests.post(url,
                          headers=headers,
                          data=data,
                          params=payload,
                          allow_redirects=False,)
        self.headers = r.headers

    def get_location(self):
        try:
            return self.headers['Location']
        except Exception as e:
            print(e)
            print("failed to get 'location' , please check your username and password or try again ")
    def get_cookie(self):
        return self.headers['Set-Cookie'].split(';')

    def get_headers(self):
        return self.headers

def construct_dict(**kw):
    return kw


#利用第二步获取的参数继续访问
class Third_request(object):

    def __init__(self, username=None, password=None):

        #获取第三次请求的地址
        r = Second_request(username=username, password=password)
        url = r.get_location()
        home_r = requests.get(url)
        self.content = home_r.text
        self.res_headers = home_r.headers
        self.req_headers = r.get_headers()
        self.login_cookie = r.login_cookie
    
    def get_req_headers(self):
        return self.req_headers

    def get_headers(self):
        return self.res_headers

    def get_cookie(self):
        return self.headers['Set-Cookie']

    def get_content(self):

        return self.content

    def get_tiezi(self):

        raw_text = self.content
        for i in [" ", "  ", "\n", "\t"]:
            raw_text = raw_text.replace(i, "A")
        pattern_s = r'<divAclass="topic"><aAhref="(.*?)"Atitle.*?Atarget="_blank">(.*?)</a></div>A最后.*?blank">(.*?)</a></span>.*?date">(.*?)</span>'
        pattern = re.compile(pattern_s, re.S)
        info_list = re.findall(pattern, raw_text)
        jar = []
        for tiezi in info_list:
            url = "https://portal.shmtu.edu.cn"+tiezi[0]
            title = tiezi[1]
            poster = tiezi[2]
            publish_date = tiezi[3]
            dic = construct_dict(url=url,
                                 title=title,
                                 poster=poster,
                                 publish_date=publish_date)
            jar.append(dic)
        return jar

    def get_card_money(self):
        try:
            pattern = re.compile(r'<span class="yue">(.*?)</span><span class="unit">元</span>', re.S)
            content = self.content
            money = re.findall(pattern, content)[0]
            money_msg = u'你的一卡通余额 %s' % (money)
        except Exception as e:
            print(e)
            return "可能是网络不太好导致无法获取一卡通信息"
        return money_msg
    
    def get_book_info(self):
        pass






if __name__ == '__main__':
    from password import my_password, my_username
    
    try:
        # print(t.get_card_money())
        # print(t.get_headers())
        # print(t.get_req_headers())
        print(t.get_tiezi())
        
        # headers = {'Cookie': t.get_cookie()}
        # content = requests.get(URL, headers=headers).text
        # print(text)
    except Exception as e:
        print(e)






#!/usr/bin/env python  
from __future__ import print_function  
from setuptools import setup, find_packages  
import sys  
  
setup(  
    name="smuer",  
    version="0.0.5",  
    author="awefight",  
    author_email="547780662@qq.com",  
    description="Easy access to SMU digital platform.",  
    license="MIT",  
    url="https://github.com/awefight/smuer",  
    packages=['smuer'],  
    install_requires=[  
        "requests>=2.13.0", 
        ],  
    classifiers=[  
        "Environment :: Web Environment",  
        "Intended Audience :: Developers",  
        "Operating System :: OS Independent",  
        "Topic :: Text Processing :: Indexing",  
        "Topic :: Utilities",  
        "Topic :: Internet",  
        "Topic :: Software Development :: Libraries :: Python Modules",  
        "Programming Language :: Python",  
        "Programming Language :: Python :: 3",  
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",  
      
    ],  
)  



#-*-coding:utf-8-*-
#coding=utf-8
#! python3

#============
#访问的是教务系统

import requests
import re


class First_request(object):

    def __init__(self, allow_redirects=None):
        URL = 'http://jwxt.shmtu.edu.cn/shmtu/home.action'
        r = requests.get(URL, allow_redirects=allow_redirects)
        self.content = r.text
        self.headers = r.headers

    def get_lt(self):
        content = self.content
        reg = r'<input type="hidden" name="lt" value="(.*)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        lt = result[0]
        return lt

    def get_execution(self):
        content = self.content
        reg = r'<input type="hidden" name="execution" value="(.*?)" />'
        pattern = re.compile(reg)
        result = pattern.findall(content)
        execution = result[0]
        return execution


    def get_cookie(self):
        return self.headers['Set-Cookie'].split(';')[0]

    def get_location(self):
        return self.headers['Location']

    def get_headers(self):
        return self.headers


class Second_request(object):

    def __init__(self,username=None, password=None):

        r1 = First_request(allow_redirects=True)
        lt = r1.get_lt()
        execution = r1.get_execution()
        login_cookie = r1.get_cookie()

        r2 = First_request(allow_redirects=False)
        url = r2.get_location()

        data = {'execution': execution,
                'username': ("%s") % username,
                'password': ("%s") % password,
                'lt': lt,
                '_eventId': 'submit',
                'signin': '登录'
               }
        headers = {'Cookie': login_cookie}
        
        r = requests.post(url,
                          headers=headers,
                          data=data,
                          allow_redirects=False,)
        self.headers = r.headers
        self.status_code = r.status_code

    def get_location(self):
        return self.headers['Location']

    def get_cookie(self):
        return self.headers['Set-Cookie'].split(';')

    def get_status(self):
        return self.status_code 

    def get_headers(self):
        return self.headers


class Third_request(object):

    def __init__(self, username=None, password=None):
        r = Second_request(username=username, password=password)
        url = r.get_location()
        next_r = requests.get(url)
        self.content = next_r.text
        self.headers = next_r.headers
        

    def get_text(self):
        return self.content
        # print(self.content)

    def get_headers(self):
        return self.headers

    def get_cookie(self):
        return self.headers['Set-Cookie']

class Fourth_request(object):

    def __init__(self,username=None, password=None):
        url = 'http://jwxt.shmtu.edu.cn/shmtu/home!childmenus.action?menu.id=22593&security.categoryId=1&_=1498735729376'
        r = Third_request(username=username, password=password)
        headers = {'Cookie': r.get_cookie()}
        r = requests.get(url, headers=headers)
        self.headers = r.headers
        self.content = r.text

    def get_text(self):
        return self.content
    # print(self.content)

    def get_headers(self):
        return self.headers

    def get_cookie(self):
        return self.headers['Set-Cookie']


class Course_table(object):

    def __init__(self, which_semester=None,username=None, password=None):
        r = Third_request(username=username, password=password)
        url = 'http://jwxt.shmtu.edu.cn/shmtu/courseTableForStd!courseTable.action'
        semester_id = 75+20*(which_semester-1) 
        data={'ignoreHead': '1',
              'setting.kind': 'std',
              'startWeek': '1',
              'semester.id': '%s' % (semester_id),
              'ids': '380129'}
        headers = {'Cookie': r.get_cookie()}
        r = requests.post(url, headers=headers, data=data)
        self.text = r.text
    def get_text(self):
        return self.text


class Course(object):
    """docstring for Course"""
    def __init__(self, which_semester, username=None, password=None):
        c = Course_table(which_semester=which_semester, username=username, password=password)
        text = c.get_text()

        #为什么下面这么蛋疼。因为脑抽了，习惯正则匹配前把一些乱七八糟的符号替换掉
        text = text.replace('+','*').replace('[','*')
        text = text.replace(']','*').replace('(','*')
        text = text.replace(')','*').replace('\n','*')
        text = text.replace('\t','*').replace(' ', '*')
        text = text.replace('*','Z')
        reg = r"newZTaskActivityZ(.*?)ZZZZactivity"
        pattern = re.compile(reg)
        result = pattern.findall(text)
        info_list = []
        for i in result:
            i = i.replace('Z','')
            i = i.split(',')
            last_str = i[-1]
            i.pop(-1)

            copy = last_str

            #课程在一学期中开课序列（o开始计数）
            course_order = copy.split(';')[0]
            # print(course_order)

            #匹配出课程在周几&第几节课（o开始计数）
            reg2 = r'index=(.*?)unitCount(.*?);'
            pattern = re.compile(reg2)
            time = pattern.findall(last_str)

            i.append(course_order)
            i.append(time)
            info_list.append(i)

        self.info_list = info_list

    def get_info_list(self):
            return self.info_list



class Lession():

    def __init__(self, info):
        self.info = info
        
        #序号
    def num(self):
        return self.info[0]

    def teacher(self):
        return self.info[1]
        #课程号
    def num2(self):
        return self.info[2]

    def name(self):
        return self.info[3]
        
        #课程号
    def num3(self):
        return self.info[4]

    def position(self):
        return self.info[5]

    #一学期下每周是否上课1为是0为否    
    def order(self):
        return self.info[6]
    
    #周几第几节
    def time(self):
        return self.info[7]

    
def construct_dic(**kw):

    return kw

def get_table(semester_id, username, password):
    c = Course(which_semester=semester_id, username=username, password=password)
    info_list = c.get_info_list()
    table = []
    for i in info_list:
        l = Lession(i)
        lession_dic = construct_dic(teacher=l.teacher(),
                                    name=l.name(),
                                    order=l.order(),
                                    position=l.position(),
                                    time = l.time(),
                                    num = l.num(),
                                    course_id = l.num2()
                                    )
        table.append(lession_dic)
    return table


if __name__ == '__main__':
    table = get_table(semester_id=1, username='', password='')
    print(table)




